@@ -49,7 +49,7 @@
 static gnutls_cert *alloc_and_load_x509_certs (gnutls_x509_crt_t * certs,
 					       unsigned);
 static gnutls_privkey *alloc_and_load_x509_key (gnutls_x509_privkey_t key);
-static gnutls_cert *alloc_and_load_pgp_certs (gnutls_openpgp_key_t cert);
+static gnutls_cert *alloc_and_load_pgp_certs (gnutls_openpgp_crt_t cert);
 static gnutls_privkey *alloc_and_load_pgp_key (const gnutls_openpgp_privkey_t
 					       key);
 
@@ -481,14 +481,14 @@ cleanup:
     {
       if (st.deinit_all)
 	{
-	  if (_E_gnutls_openpgp_key_deinit == NULL ||
+	  if (_E_gnutls_openpgp_crt_deinit == NULL ||
 	      _E_gnutls_openpgp_privkey_deinit == NULL)
 	    {
 	      gnutls_assert ();
 	      return GNUTLS_E_INIT_LIBEXTRA;
 	    }
 
-	  _E_gnutls_openpgp_key_deinit (st.cert.pgp);
+	  _E_gnutls_openpgp_crt_deinit (st.cert.pgp);
 	  _E_gnutls_openpgp_privkey_deinit (st.key.pgp);
 	}
     }
@@ -1583,7 +1583,7 @@ alloc_and_load_x509_key (gnutls_x509_privkey_t key)
  * space for them.
  */
 static gnutls_cert *
-alloc_and_load_pgp_certs (gnutls_openpgp_key_t cert)
+alloc_and_load_pgp_certs (gnutls_openpgp_crt_t cert)
 {
   gnutls_cert *local_certs;
   int ret = 0;
@@ -1598,13 +1598,13 @@ alloc_and_load_pgp_certs (gnutls_openpgp_key_t cert)
       return NULL;
     }
 
-  if (_E_gnutls_openpgp_key_to_gcert == NULL)
+  if (_E_gnutls_openpgp_crt_to_gcert == NULL)
     {
       gnutls_assert ();
       return NULL;
     }
 
-  ret = _E_gnutls_openpgp_key_to_gcert (local_certs, cert);
+  ret = _E_gnutls_openpgp_crt_to_gcert (local_certs, cert);
   if (ret < 0)
     {
       gnutls_assert ();
