@@ -28,6 +28,8 @@
 #include "gnutls_cert.h"
 #include <x509/common.h>
 
+
+
 /* Cred type mappings to KX algorithms 
  * FIXME: The mappings are not 1-1. Some KX such as SRP_RSA require
  * more than one credentials type.
@@ -114,10 +116,10 @@ typedef struct
 } gnutls_version_entry;
 
 static const gnutls_version_entry sup_versions[] = {
-  {"SSL 3.0", GNUTLS_SSL3, 3, 0, 1},
-  {"TLS 1.0", GNUTLS_TLS1, 3, 1, 1},
-  {"TLS 1.1", GNUTLS_TLS1_1, 3, 2, 1},
-  {"TLS 1.2", GNUTLS_TLS1_2, 3, 3, 1},
+  {"SSL3.0", GNUTLS_SSL3, 3, 0, 1},
+  {"TLS1.0", GNUTLS_TLS1, 3, 1, 1},
+  {"TLS1.1", GNUTLS_TLS1_1, 3, 2, 1},
+  {"TLS1.2", GNUTLS_TLS1_2, 3, 3, 1},
   {0, 0, 0, 0, 0}
 };
 
@@ -156,17 +158,17 @@ typedef struct gnutls_cipher_entry gnutls_cipher_entry;
  * protecting communications" by Hugo Krawczyk - CRYPTO 2001
  */
 static const gnutls_cipher_entry algorithms[] = {
-  {"AES 256 CBC", GNUTLS_CIPHER_AES_256_CBC, 16, 32, CIPHER_BLOCK, 16, 0},
-  {"AES 128 CBC", GNUTLS_CIPHER_AES_128_CBC, 16, 16, CIPHER_BLOCK, 16, 0},
-  {"3DES 168 CBC", GNUTLS_CIPHER_3DES_CBC, 8, 24, CIPHER_BLOCK, 8, 0},
-  {"DES CBC", GNUTLS_CIPHER_DES_CBC, 8, 8, CIPHER_BLOCK, 8, 0},
-  {"ARCFOUR 128", GNUTLS_CIPHER_ARCFOUR_128, 1, 16, CIPHER_STREAM, 0, 0},
-  {"ARCFOUR 40", GNUTLS_CIPHER_ARCFOUR_40, 1, 5, CIPHER_STREAM, 0, 1},
-  {"RC2 40", GNUTLS_CIPHER_RC2_40_CBC, 8, 5, CIPHER_BLOCK, 8, 1},
+  {"AES-256-CBC", GNUTLS_CIPHER_AES_256_CBC, 16, 32, CIPHER_BLOCK, 16, 0},
+  {"AES-128-CBC", GNUTLS_CIPHER_AES_128_CBC, 16, 16, CIPHER_BLOCK, 16, 0},
+  {"3DES-CBC", GNUTLS_CIPHER_3DES_CBC, 8, 24, CIPHER_BLOCK, 8, 0},
+  {"DES-CBC", GNUTLS_CIPHER_DES_CBC, 8, 8, CIPHER_BLOCK, 8, 0},
+  {"ARCFOUR-128", GNUTLS_CIPHER_ARCFOUR_128, 1, 16, CIPHER_STREAM, 0, 0},
+  {"ARCFOUR-40", GNUTLS_CIPHER_ARCFOUR_40, 1, 5, CIPHER_STREAM, 0, 1},
+  {"RC2-40", GNUTLS_CIPHER_RC2_40_CBC, 8, 5, CIPHER_BLOCK, 8, 1},
 #ifdef	ENABLE_CAMELLIA
-  {"CAMELLIA 256 CBC", GNUTLS_CIPHER_CAMELLIA_256_CBC, 16, 32, CIPHER_BLOCK,
+  {"CAMELLIA-256-CBC", GNUTLS_CIPHER_CAMELLIA_256_CBC, 16, 32, CIPHER_BLOCK,
    16, 0},
-  {"CAMELLIA 128 CBC", GNUTLS_CIPHER_CAMELLIA_128_CBC, 16, 16, CIPHER_BLOCK,
+  {"CAMELLIA-128-CBC", GNUTLS_CIPHER_CAMELLIA_128_CBC, 16, 16, CIPHER_BLOCK,
    16, 0},
 #endif
   {"NULL", GNUTLS_CIPHER_NULL, 1, 0, CIPHER_STREAM, 0, 0},
@@ -208,7 +210,7 @@ struct gnutls_hash_entry
 typedef struct gnutls_hash_entry gnutls_hash_entry;
 
 static const gnutls_hash_entry hash_algorithms[] = {
-  {"SHA", HASH_OID_SHA1, GNUTLS_MAC_SHA1, 20},
+  {"SHA1", HASH_OID_SHA1, GNUTLS_MAC_SHA1, 20},
   {"MD5", HASH_OID_MD5, GNUTLS_MAC_MD5, 16},
   {"SHA256", HASH_OID_SHA256, GNUTLS_MAC_SHA256, 32},
   {"SHA384", HASH_OID_SHA384, GNUTLS_MAC_SHA384, 48},
@@ -305,22 +307,22 @@ typedef struct gnutls_kx_algo_entry gnutls_kx_algo_entry;
 
 static const gnutls_kx_algo_entry _gnutls_kx_algorithms[] = {
 #ifdef ENABLE_ANON
-  {"Anon DH", GNUTLS_KX_ANON_DH, &anon_auth_struct, 1, 0},
+  {"ANON-DH", GNUTLS_KX_ANON_DH, &anon_auth_struct, 1, 0},
 #endif
   {"RSA", GNUTLS_KX_RSA, &rsa_auth_struct, 0, 0},
-  {"RSA EXPORT", GNUTLS_KX_RSA_EXPORT, &rsa_export_auth_struct, 0,
+  {"RSA-EXPORT", GNUTLS_KX_RSA_EXPORT, &rsa_export_auth_struct, 0,
    1 /* needs RSA params */ },
-  {"DHE RSA", GNUTLS_KX_DHE_RSA, &dhe_rsa_auth_struct, 1, 0},
-  {"DHE DSS", GNUTLS_KX_DHE_DSS, &dhe_dss_auth_struct, 1, 0},
+  {"DHE-RSA", GNUTLS_KX_DHE_RSA, &dhe_rsa_auth_struct, 1, 0},
+  {"DHE-DSS", GNUTLS_KX_DHE_DSS, &dhe_dss_auth_struct, 1, 0},
 
 #ifdef ENABLE_SRP
-  {"SRP DSS", GNUTLS_KX_SRP_DSS, &srp_dss_auth_struct, 0, 0},
-  {"SRP RSA", GNUTLS_KX_SRP_RSA, &srp_rsa_auth_struct, 0, 0},
+  {"SRP-DSS", GNUTLS_KX_SRP_DSS, &srp_dss_auth_struct, 0, 0},
+  {"SRP-RSA", GNUTLS_KX_SRP_RSA, &srp_rsa_auth_struct, 0, 0},
   {"SRP", GNUTLS_KX_SRP, &srp_auth_struct, 0, 0},
 #endif
 #ifdef ENABLE_PSK
   {"PSK", GNUTLS_KX_PSK, &psk_auth_struct, 0, 0},
-  {"DHE PSK", GNUTLS_KX_DHE_PSK, &dhe_psk_auth_struct,
+  {"DHE-PSK", GNUTLS_KX_DHE_PSK, &dhe_psk_auth_struct,
    1 /* needs DHE params */ , 0},
 #endif
   {0, 0, 0, 0, 0}
@@ -406,8 +408,7 @@ typedef struct
 #define GNUTLS_DHE_PSK_SHA_AES_256_CBC_SHA1 { 0x00, 0x91 }
 
 
-/* SRP (not in TLS 1.0)
- * draft-ietf-tls-srp-14:
+/* SRP (rfc5054)
  */
 #define GNUTLS_SRP_SHA_3DES_EDE_CBC_SHA1 { 0xC0, 0x1A }
 #define GNUTLS_SRP_SHA_RSA_3DES_EDE_CBC_SHA1 { 0xC0, 0x1B }
@@ -652,7 +653,7 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 
 /* Generic Functions */
 
-inline int
+int
 _gnutls_mac_priority (gnutls_session_t session,
 		      gnutls_mac_algorithm_t algorithm)
 {				/* actually returns the priority */
@@ -683,6 +684,26 @@ gnutls_mac_get_name (gnutls_mac_algorithm_t algorithm)
   return ret;
 }
 
+/**
+  * gnutls_mac_get_id - Returns the gnutls id of the specified in string algorithm
+  * @algorithm: is a MAC algorithm name
+  *
+  * Returns an id of the specified in a string MAC algorithm. The names are
+  * compared in a case insensitive way.
+  *
+  * Returns GNUTLS_MAC_UNKNOWN on error.
+  *
+  **/
+gnutls_mac_algorithm_t
+gnutls_mac_get_id (const char* name)
+{
+  gnutls_mac_algorithm_t ret = GNUTLS_MAC_UNKNOWN;
+
+  GNUTLS_HASH_LOOP( if (strcasecmp( p->name, name)==0) ret = p->id);
+
+  return ret;
+}
+
 /**
   * gnutls_mac_get_key_size - Returns the length of the MAC's key size
   * @algorithm: is an encryption algorithm
@@ -760,7 +781,7 @@ _gnutls_mac_is_ok (gnutls_mac_algorithm_t algorithm)
 }
 
 /* Compression Functions */
-inline int
+int
 _gnutls_compression_priority (gnutls_session_t session,
 			      gnutls_compression_method_t algorithm)
 {				/* actually returns the priority */
@@ -793,6 +814,26 @@ gnutls_compression_get_name (gnutls_compression_method_t algorithm)
   return ret;
 }
 
+/**
+  * gnutls_compression_get_id - Returns the gnutls id of the specified in string algorithm
+  * @algorithm: is a compression method name
+  *
+  * Returns an id of the specified in a string compression method. The names are
+  * compared in a case insensitive way.
+  *
+  * Returns GNUTLS_COMP_UNKNOWN on error.
+  *
+  **/
+gnutls_compression_method_t
+gnutls_compression_get_id (const char* name)
+{
+  gnutls_compression_method_t ret = GNUTLS_COMP_UNKNOWN;
+
+  GNUTLS_COMPRESSION_LOOP( if (strcasecmp( p->name+sizeof("GNUTLS_COMP_")-1, name)==0) ret = p->id);
+
+  return ret;
+}
+
 /**
  * gnutls_compression_list:
  *
@@ -888,7 +929,7 @@ _gnutls_cipher_get_block_size (gnutls_cipher_algorithm_t algorithm)
 }
 
  /* returns the priority */
-inline int
+int
 _gnutls_cipher_priority (gnutls_session_t session,
 			 gnutls_cipher_algorithm_t algorithm)
 {
@@ -967,6 +1008,26 @@ gnutls_cipher_get_name (gnutls_cipher_algorithm_t algorithm)
   return ret;
 }
 
+/**
+  * gnutls_cipher_get_id - Returns the gnutls id of the specified in string algorithm
+  * @algorithm: is a MAC algorithm name
+  *
+  * Returns an id of the specified cipher. The names are
+  * compared in a case insensitive way.
+  *
+  * Returns GNUTLS_CIPHER_UNKNOWN on error.
+  *
+  **/
+gnutls_cipher_algorithm_t
+gnutls_cipher_get_id (const char* name)
+{
+  gnutls_cipher_algorithm_t ret = GNUTLS_CIPHER_UNKNOWN;
+
+  GNUTLS_LOOP( if (strcasecmp( p->name, name)==0) ret = p->id);
+
+  return ret;
+}
+
 /**
  * gnutls_cipher_list:
  *
@@ -1009,7 +1070,7 @@ _gnutls_kx_auth_struct (gnutls_kx_algorithm_t algorithm)
 }
 
 
-inline int
+int
 _gnutls_kx_priority (gnutls_session_t session,
 		     gnutls_kx_algorithm_t algorithm)
 {
@@ -1040,6 +1101,26 @@ gnutls_kx_get_name (gnutls_kx_algorithm_t algorithm)
   return ret;
 }
 
+/**
+  * gnutls_kx_get_id - Returns the gnutls id of the specified in string algorithm
+  * @algorithm: is a KX name
+  *
+  * Returns an id of the specified KX algorithm. The names are
+  * compared in a case insensitive way.
+  *
+  * Returns GNUTLS_KX_UNKNOWN on error.
+  *
+  **/
+gnutls_kx_algorithm_t
+gnutls_kx_get_id (const char* name)
+{
+  gnutls_cipher_algorithm_t ret = GNUTLS_KX_UNKNOWN;
+
+  GNUTLS_KX_LOOP( if (strcasecmp( p->name, name)==0) ret = p->algorithm);
+
+  return ret;
+}
+
 /**
  * gnutls_kx_list:
  *
@@ -1166,6 +1247,26 @@ gnutls_protocol_get_name (gnutls_protocol_t version)
   return ret;
 }
 
+/**
+  * gnutls_protocol_get_id - Returns the gnutls id of the specified in string protocol
+  * @algorithm: is a protocol name
+  *
+  * Returns an id of the specified protocol. The names are
+  * compared in a case insensitive way.
+  *
+  * Returns GNUTLS_VERSION_UNKNOWN on error.
+  *
+  **/
+gnutls_protocol_t
+gnutls_protocol_get_id (const char* name)
+{
+  gnutls_protocol_t ret = GNUTLS_VERSION_UNKNOWN;
+
+  GNUTLS_VERSION_LOOP( if (strcasecmp( p->name, name)==0) ret = p->id);
+
+  return ret;
+}
+
 /**
  * gnutls_protocol_list:
  *
@@ -1385,7 +1486,7 @@ gnutls_cipher_suite_info (size_t idx,
 }
 
 
-inline static int
+static inline int
 _gnutls_cipher_suite_is_ok (cipher_suite_st * suite)
 {
   size_t ret;
@@ -1405,7 +1506,7 @@ _gnutls_cipher_suite_is_ok (cipher_suite_st * suite)
 		   memcpy(y,tmp,size);
 
 #define MAX_ELEM_SIZE 4
-inline static int
+static inline int
 _gnutls_partition (gnutls_session_t session, void *_base,
 		   size_t nmemb, size_t size,
 		   int (*compar) (gnutls_session_t,
@@ -1746,6 +1847,29 @@ gnutls_certificate_type_get_name (gnutls_certificate_type_t type)
   return ret;
 }
 
+/**
+  * gnutls_certificate_type_get_id - Returns the gnutls id of the specified in string type
+  * @name: is a certificate type name
+  *
+  * Returns an id of the specified in a string certificate type. The names are
+  * compared in a case insensitive way.
+  *
+  * Returns GNUTLS_CRT_UNKNOWN on error.
+  *
+  **/
+gnutls_certificate_type_t
+gnutls_certificate_type_get_id (const char* name)
+{
+  gnutls_certificate_type_t ret = GNUTLS_CRT_UNKNOWN;
+
+  if (strcasecmp( name, "X.509")==0 || strcasecmp( name, "X509")==0)
+    return GNUTLS_CRT_X509;
+  if (strcasecmp( name, "OPENPGP")==0)
+    return GNUTLS_CRT_OPENPGP;
+  
+  return ret;
+}
+
 static const gnutls_certificate_type_t supported_certificate_types[] = {
   GNUTLS_CRT_X509,
   GNUTLS_CRT_OPENPGP,
