@@ -216,8 +216,8 @@ static const gnutls_error_entry error_algorithms[] = {
 	       GNUTLS_E_X509_UNSUPPORTED_ATTRIBUTE, 1),
   ERROR_ENTRY (N_("The OID is not supported."), GNUTLS_E_X509_UNSUPPORTED_OID,
 	       1),
-  ERROR_ENTRY (N_("The hash algorithm is unknown."),
-	       GNUTLS_E_UNKNOWN_HASH_ALGORITHM, 1),
+  ERROR_ENTRY (N_("The specified algorithm or protocol is unknown."),
+	       GNUTLS_E_UNKNOWN_ALGORITHM, 1),
   ERROR_ENTRY (N_("The PKCS structure's content type is unknown."),
 	       GNUTLS_E_UNKNOWN_PKCS_CONTENT_TYPE, 1),
   ERROR_ENTRY (N_("The PKCS structure's bag type is unknown."),
