@@ -31,6 +31,10 @@
 #include <gnutls/gnutls.h>
 #include <gnutls/extra.h>
 
+/* FIXME: delete this once opencdk has reentrant keyring functions
+ */
+#define KEYRING_HACK
+
 /*
  * They are not needed any more. You can simply enable
  * the gnutls_log callback to get error descriptions.
@@ -458,6 +462,9 @@ typedef struct
 
   /* sockets internals */
   int lowat;
+  
+  /* to disable record padding */
+  int no_padding;
 
   /* These buffers are used in the handshake
    * protocol only. freed using _gnutls_handshake_io_buffer_clear();
