@@ -440,8 +440,8 @@ _gnutls_dsa_sign (gnutls_datum_t * signature,
   size_t k;
 
   k = hash->size;
-  if (k != 20)
-    {				/* SHA only */
+  if (k < 20)
+    {				/* SHA1 or better only */
       gnutls_assert ();
       return GNUTLS_E_PK_SIGN_FAILED;
     }
