@@ -83,6 +83,25 @@ gnutls_transport_set_lowat (gnutls_session_t session, int num)
   session->internals.lowat = num;
 }
 
+/**
+  * gnutls_record_disable_padding - Used to disabled padding in TLS 1.0 and above
+  * @session: is a #gnutls_session_t structure.
+  *
+  * Used to disabled padding in TLS 1.0 and above. Normally you do not need
+  * to use this function, but there are buggy clients that complain if a
+  * server pads the encrypted data. This of course will disable protection
+  * against statistical attacks on the data.
+  *
+  * Normally only servers that require maximum compatibility with everything
+  * out there, need to call this function.
+  *
+  **/
+void
+gnutls_record_disable_padding (gnutls_session_t session)
+{
+  session->internals.no_padding = 1;
+}
+
 /**
   * gnutls_transport_set_ptr - Used to set first argument of the transport functions
   * @session: is a #gnutls_session_t structure.
@@ -321,8 +340,6 @@ _gnutls_send_int (gnutls_session_t session, content_type_t type,
   int data2send_size;
   uint8_t headers[5];
   const uint8_t *data = _data;
-  int erecord_size = 0;
-  opaque *erecord = NULL;
 
   /* Do not allow null pointer if the send buffer is empty.
    * If the previous send was interrupted then a null pointer is
@@ -342,8 +359,6 @@ _gnutls_send_int (gnutls_session_t session, content_type_t type,
 	return GNUTLS_E_INVALID_SESSION;
       }
 
-
-
   headers[0] = type;
 
   /* Use the default record version, if it is
@@ -399,7 +414,6 @@ _gnutls_send_int (gnutls_session_t session, content_type_t type,
 	  gnutls_assert ();
 	  if (cipher_size == 0)
 	    cipher_size = GNUTLS_E_ENCRYPTION_FAILED;
-	  gnutls_afree (erecord);
 	  gnutls_free (cipher);
 	  return cipher_size;	/* error */
 	}
@@ -414,19 +428,16 @@ _gnutls_send_int (gnutls_session_t session, content_type_t type,
 	{
 	  session_invalidate (session);
 	  gnutls_assert ();
-	  gnutls_afree (erecord);
 	  gnutls_free (cipher);
 	  return GNUTLS_E_RECORD_LIMIT_REACHED;
 	}
 
       ret =
-	_gnutls_io_write_buffered2 (session, erecord, erecord_size,
-				    cipher, cipher_size);
-      gnutls_afree (erecord);
+	_gnutls_io_write_buffered (session, cipher, cipher_size);
       gnutls_free (cipher);
     }
 
-  if (ret != cipher_size + erecord_size)
+  if (ret != cipher_size)
     {
       if (ret < 0 && gnutls_error_is_fatal (ret) == 0)
 	{
@@ -777,19 +788,13 @@ record_check_type (gnutls_session_t session,
 inline static int
 get_temp_recv_buffer (gnutls_session_t session, gnutls_datum_t * tmp)
 {
-size_t max_record_size;
-
-  if (gnutls_compression_get(session) != GNUTLS_COMP_NULL)
-    max_record_size = MAX_RECORD_RECV_SIZE + EXTRA_COMP_SIZE;
-  else
-    max_record_size = MAX_RECORD_RECV_SIZE;
 
   /* We allocate MAX_RECORD_RECV_SIZE length
    * because we cannot predict the output data by the record
    * packet length (due to compression).
    */
 
-  if (max_record_size > session->internals.recv_buffer.size ||
+  if (MAX_RECORD_RECV_SIZE > session->internals.recv_buffer.size ||
       session->internals.recv_buffer.data == NULL)
     {
 
@@ -797,7 +802,7 @@ size_t max_record_size;
        */
       session->internals.recv_buffer.data =
 	gnutls_realloc (session->internals.recv_buffer.data,
-			max_record_size);
+			MAX_RECORD_RECV_SIZE);
 
       if (session->internals.recv_buffer.data == NULL)
 	{
@@ -805,7 +810,7 @@ size_t max_record_size;
 	  return GNUTLS_E_MEMORY_ERROR;
 	}
 
-      session->internals.recv_buffer.size = max_record_size;
+      session->internals.recv_buffer.size = MAX_RECORD_RECV_SIZE;
     }
 
   tmp->data = session->internals.recv_buffer.data;
@@ -1217,23 +1222,3 @@ gnutls_record_set_max_size (gnutls_session_t session, size_t size)
 
   return 0;
 }
-
-/**
-  * gnutls_record_disable_padding - Used to disabled padding in TLS 1.0 and above
-  * @session: is a #gnutls_session_t structure.
-  *
-  * Used to disabled padding in TLS 1.0 and above. Normally you do not need
-  * to use this function, but there are buggy clients that complain if a
-  * server pads the encrypted data. This of course will disable protection
-  * against statistical attacks on the data.
-  *
-  * Normally only servers that require maximum compatibility with everything
-  * out there, need to call this function.
-  *
-  **/
-void gnutls_record_disable_padding (gnutls_session_t session)
- {
-   session->internals.no_padding = 1;
- }
- 
- 
\ No newline at end of file
