@@ -8,18 +8,14 @@ typedef struct _gaainfo gaainfo;
 
 struct _gaainfo
 {
-#line 122 "cli.gaa"
+#line 116 "cli.gaa"
 	char *rest_args;
-#line 113 "cli.gaa"
-	int insecure;
-#line 110 "cli.gaa"
-	char *port;
 #line 107 "cli.gaa"
-	char *opaque_prf_input;
+	int insecure;
 #line 104 "cli.gaa"
-	char *authz_saml_assertion;
+	char *port;
 #line 101 "cli.gaa"
-	char *authz_x509_attr_cert;
+	char *opaque_prf_input;
 #line 98 "cli.gaa"
 	char *psk_key;
 #line 95 "cli.gaa"
