@@ -32,6 +32,7 @@
 #include <sys/types.h>
 #include <string.h>
 #include <gnutls/gnutls.h>
+#include <gcrypt.h>
 #include <gnutls/extra.h>
 #include <sys/time.h>
 #include <fcntl.h>
@@ -379,7 +380,7 @@ initialize_session (void)
       gnutls_db_set_ptr (session, NULL);
     }
 
-  gnutls_set_default_priority (session);
+  gnutls_set_default_priority2 (session, GNUTLS_PRIORITIES_PERFORMANCE);
 
   if (cipher_priority[0])
     gnutls_cipher_set_priority (session, cipher_priority);
@@ -414,6 +415,11 @@ initialize_session (void)
       gnutls_certificate_server_set_request (session, GNUTLS_CERT_REQUEST);
   }
 
+  /* Set maximum compatibility mode. This is only suggested on public webservers
+   * that need to trade security for compatibility
+   */
+   gnutls_session_enable_compatibility_mode( session);
+
 #ifdef ENABLE_OPRFI
   if (info.opaque_prf_input)
     gnutls_oprfi_enable_server (session, oprfi_callback, NULL);
@@ -817,6 +823,8 @@ main (int argc, char **argv)
       strcpy (name, "Echo Server");
     }
 
+  gcry_control (GCRYCTL_ENABLE_QUICK_RANDOM, 0);
+
   if ((ret = gnutls_global_init ()) < 0)
     {
       fprintf (stderr, "global_init: %s\n", gnutls_strerror (ret));
@@ -890,7 +898,7 @@ main (int argc, char **argv)
   if (pgp_keyring != NULL)
     {
       ret =
-	gnutls_certificate_set_openpgp_keyring_file (cert_cred, pgp_keyring);
+	gnutls_certificate_set_openpgp_keyring_file (cert_cred, pgp_keyring, GNUTLS_OPENPGP_FMT_BASE64);
       if (ret < 0)
 	{
 	  fprintf (stderr, "Error setting the OpenPGP keyring file\n");
@@ -900,7 +908,7 @@ main (int argc, char **argv)
 
   if (pgp_certfile != NULL)
     if ((ret = gnutls_certificate_set_openpgp_key_file
-	 (cert_cred, pgp_certfile, pgp_keyfile)) < 0)
+	 (cert_cred, pgp_certfile, pgp_keyfile, GNUTLS_OPENPGP_FMT_BASE64)) < 0)
       {
 	fprintf (stderr,
 		 "Error[%d] while reading the OpenPGP key pair ('%s', '%s')\n",
