@@ -129,6 +129,10 @@ static const TLS_TEST tls_tests[] = {
    "N/A"},
   {"for AES cipher support (TLS extension)", test_aes, "yes", "no",
    "dunno"},
+#ifdef	ENABLE_CAMELLIA
+  {"for CAMELLIA cipher support (TLS extension)", test_camellia, "yes", "no",
+   "dunno"},
+#endif
   {"for 3DES cipher support", test_3des, "yes", "no", "dunno"},
   {"for ARCFOUR 128 cipher support", test_arcfour, "yes", "no", "dunno"},
   {"for ARCFOUR 40 cipher support", test_arcfour_40, "yes", "no",
